@@ -1,6 +1,8 @@
 import motor.motor_asyncio
 
-from lightning_fast.mongodb.clients.client_descriptor.base.client_descriptor_base import ClientDescriptorBase
+from lightning_fast.mongodb.clients.client_descriptor.base.client_descriptor_base import (
+    ClientDescriptorBase,
+)
 
 
 class AsyncMongodbClient(ClientDescriptorBase):
